@@ -3,17 +3,12 @@
 import json
 import logging
 from pathlib import Path
-from typing import List, Optional, Tuple
+from typing import List, Optional
 
 from PIL import Image
 
-from .config import BackgroundConfig, ProjectConfig, ScreenshotConfig, TextOverlay
-from .exceptions import (
-    BackgroundRenderError,
-    DeviceFrameError,
-    RenderError,
-    TextRenderError,
-)
+from .config import GradientConfig, ProjectConfig, ScreenshotConfig, TextOverlay
+from .exceptions import RenderError
 from .renderers.background import BackgroundRenderer
 from .renderers.device_frame import DeviceFrameRenderer
 from .renderers.text import TextRenderer
@@ -22,7 +17,7 @@ logger = logging.getLogger(__name__)
 
 
 class ScreenshotGenerator:
-    """Main class for generating screenshots with backgrounds, text, and device frames."""
+    """Main class for generating screenshots with backgrounds, text, and frames."""
 
     def __init__(self, frame_directory: Optional[str] = None):
         """Initialize the screenshot generator.
@@ -125,7 +120,6 @@ class ScreenshotGenerator:
 
             # Ensure output directory exists
             output_path.parent.mkdir(parents=True, exist_ok=True)
-            
             # Convert to RGB if saving as JPEG, keep RGBA for PNG
             if output_path.suffix.lower() == ".jpg":
                 # Create white background for JPEG
@@ -153,7 +147,9 @@ class ScreenshotGenerator:
                 image = image.convert("RGBA")
             return image
         except Exception as _e:
-            raise RenderError(f"Failed to load source image '{image_path}': {_e}") from _e
+            raise RenderError(
+                f"Failed to load source image '{image_path}': {_e}"
+            ) from _e
 
     def _position_source_image(
         self, source_image: Image.Image, canvas: Image.Image, config: ScreenshotConfig
@@ -168,7 +164,8 @@ class ScreenshotGenerator:
         scaled_height = int(original_height * scale_factor)
 
         logger.info(
-            "📏 Scaling image: {original_width}×{original_height} → {scaled_width}×{scaled_height} (scale: {scale_factor})"
+            "📏 Scaling image: {original_width}×{original_height} → "
+            "{scaled_width}×{scaled_height} (scale: {scale_factor})"
         )
 
         # Resize the source image
@@ -190,7 +187,8 @@ class ScreenshotGenerator:
         y = center_y - scaled_height // 2
 
         logger.info(
-            "📐 Positioning asset: center at {position} → ({center_x}, {center_y}), top-left at ({x}, {y})"
+            "📐 Positioning asset: center at {position} → "
+            "({center_x}, {center_y}), top-left at ({x}, {y})"
         )
 
         # Create positioned image
@@ -361,7 +359,9 @@ class ScreenshotGenerator:
 
         results = []
         for i, screenshot_def in enumerate(project_config.screenshots, 1):
-            logger.info(f"[{i}/{len(project_config.screenshots)}] {screenshot_def.name}")
+            logger.info(
+                f"[{i}/{len(project_config.screenshots)}] {screenshot_def.name}"
+            )
             try:
                 # Convert to ScreenshotConfig and generate
                 temp_config = self._convert_to_screenshot_config(
@@ -439,7 +439,8 @@ class ScreenshotGenerator:
                     "frame": getattr(item, "frame", False),  # Capture frame setting
                 }
                 logger.info(
-                    "📏 Image: scale={image_scale * 100:.0f}%, position={image_position}, frame={getattr(item, 'frame', False)}"
+                    f"📏 Image: scale={image_scale * 100:.0f}%, "
+                    f"position={image_position}, frame={getattr(item, 'frame', False)}"
                 )
                 break  # Use first image found
 
@@ -505,7 +506,8 @@ class ScreenshotGenerator:
                         position=position,
                         font_size=item.size or 24,
                         font_weight=getattr(item, "weight", "normal") or "normal",
-                        color=item.color or "#000000",
+                        color=item.color,  # Don't default to black if gradient is provided
+                        gradient=item.gradient,  # Pass gradient configuration
                         alignment=getattr(item, "alignment", "center") or "center",
                         anchor="center",  # Use center anchor for percentage-based positioning
                         max_width=getattr(
@@ -514,17 +516,31 @@ class ScreenshotGenerator:
                         max_lines=getattr(
                             item, "maxLines", None
                         ),  # None means unlimited lines with wrapping
+                        stroke_width=getattr(item, "stroke_width", None),
+                        stroke_color=getattr(item, "stroke_color", None),
+                        stroke_gradient=getattr(item, "stroke_gradient", None),
                     )
                     text_overlays.append(text_overlay)
 
-        # Create background config
+        # Create background config with priority: screenshot background > default background > white
         background_config = None
-        if default_background:
-            background_config = BackgroundConfig(
+        if screenshot_def.background:
+            # Use per-screenshot background if specified
+            background_config = screenshot_def.background
+        elif default_background:
+            # Fallback to project default background
+            background_config = GradientConfig(
                 type=default_background.get("type", "solid"),
-                colors=default_background.get("colors", ["#fffff"]),
+                colors=default_background.get("colors", ["#ffffff"]),
                 direction=default_background.get("direction", 0),
+                positions=default_background.get("positions"),
+                center=default_background.get("center"),
+                radius=default_background.get("radius"),
+                start_angle=default_background.get("start_angle"),
             )
+        else:
+            # Final fallback to white background
+            background_config = GradientConfig(type="solid", colors=["#ffffff"])
 
         # Create screenshot config with calculated dimensions
         # Store scale factor for use during generation
